
Limiting the size of user input
-------

**Description:**

Whenever there is userinput supplied into your application you also want to limit
the size of the userinput to appropriate maximum lengths.
 
**Solution:**

Verify that XML or JSON schema are in place and verified before accepting input.

Recommended knowledge base items:

- Input rejection
- Input validation
- Audit logs


